import type {
  UserLoginRequest,
  CurrentUser,
  CreateUser,
  Users,
} from "@/types/user.types";
import type { Page } from "@/types/pagination.types";
import type { Response } from "@/types/response.types";
import type { AxiosResponse } from "axios";
import httpClient from "./httpClient";
import _ from "lodash";

export function withPrefix(prefix: string) {
  return (path?: string | number) => {
    if (path) {
      return _.trimEnd(prefix, "/") + "/" + _.trimStart(`${path}`, "/");
    }
    return prefix;
  };
}

const urlPrefix = "/api";

const _url = withPrefix(urlPrefix);

function login(
  param: UserLoginRequest
): Promise<AxiosResponse<Response<CurrentUser>>> {
  return httpClient.post<Response<CurrentUser>>(_url("/login"), param);
}

async function checkLogin(): Promise<boolean> {
  const resp = await httpClient.get(_url("/user/checkLogin"));
  if (resp) {
    return true;
  }
  return false;
}

function createUser(
  param: CreateUser
): Promise<AxiosResponse<Response<CreateUser>>> {
  return httpClient.post<Response<CreateUser>>(_url("/user"), param);
}

function users(
  page: number = 1
): Promise<AxiosResponse<Response<Page<Users>>>> {
  return httpClient.get<Response<Page<Users>>>(
    _url(`/user/users?page=${page}`)
  );
}

function updateIsDisable(id: number) {
  return httpClient.put(_url(`/user/updateIsDisable/${id}`));
}

function updatePassword(data: any) {
  return httpClient.put(_url("/user/updatePasswordByPhone"), data);
}

async function logout() {
  const resp = await httpClient.get(_url("/user/logout"));
  return resp;
}

export default {
  login,
  checkLogin,
  logout,
  createUser,
  users,
  updateIsDisable,
  updatePassword,
};
